<?php
namespace Webberdoo\BTC\AppBundle\Controllers;

use Silex\Application;
use WP_Query;

/**
 * Created by Freddie Annobil-Dodoo @ Webberdoo.co.uk
 * OptionController to set up with ACF Pro Options Page
 */
class OptionController
{
    /**
     * @var Application
     */
    public $app;

    /**
     * OptionClass constructor.
     * @param Application $app
     */
    public function __construct(Application $app)
    {
        $this->app = $app;
    }

    /**
     *inity add actions
     */
    public function init()
    {
        // Add the custom columns to the custom post types:
        add_filter( 'manage_wdoo_btc_donate_posts_columns', array($this,'set_custom_edit_bitcoindonate_columns'), 10 );
        // Add the data to the custom columns for custom post types:
        add_action( 'manage_wdoo_btc_donate_posts_custom_column' , array($this,'custom_bitcoindonate_column'), 10, 2 );
        //remove 'view' link from admin column
        add_filter( 'post_row_actions', array($this,'remove_row_actions'), 10, 1 );

        //reset results
      //  add_action('acf/save_post', array($this,'reset_result'), 20);

        $this->add_acf_option_page();
    }




    //add ACF Pro options page
    public function add_acf_option_page()
    {
	    acf_add_options_page(array(
		    'page_title' 	=> 'Localisation',
		    'menu_title'	=> 'Localisation',
		    'menu_slug' 	=> 'wdoo-btc',
		    'capability'	=> 'edit_posts',
		    'parent_slug'	=> 'edit.php?post_type=wdoo_btc_donate',
		    'redirect'		=> false,
		    'position'      => false
	    ));
    }


	//remove 'view' link from admin column
	public function remove_row_actions( $actions )
	{
		if( get_post_type() === 'wdoo_btc_donate' )
			unset( $actions['view'] );
		return $actions;
	}


    //-----------------------------------------------------------------------------------------------------------
    //          ADD CUSTOM COLUMNS FOR - STANDARD POST TYPE
    //-----------------------------------------------------------------------------------------------------------
    // Add the custom columns to the emails post type:
    public function set_custom_edit_bitcoindonate_columns($columns)
    {
        //  unset( $columns['title'] );
        // $columns['voter_standard_shortcode'] = __( 'Shortcode', 'your_text_domain' );
        // $columns['votr_email_address'] = __( 'Emaill Address', 'your_text_domain' );

        //return $columns;
        # add your column key to the existing columns.
        $columns['bitcoindonate_shortcode'] = __('Bitcoin Donate Shortcode');
     //   $columns['voter_standard_result_shortcode'] = __('Results Shortcode');

        # now define a new order. you need to look up the column
        # names in the HTML of the admin interface HTML of the table header.
        #   "cb" is the "select all" checkbox.
        #   "title" is the title column.
        #   "date" is the date column.
        #   "icl_translations" comes from a plugin (in this case, WPML).
        # change the order of the names to change the order of the columns.
        if ($columns['icl_translations']) {
            $customOrder = array('cb', 'title', 'icl_translations', 'bitcoindonate_shortcode', 'date');
        } else {
            $customOrder = array('cb', 'title', 'bitcoindonate_shortcode', 'date');
        }


        # return a new column array to wordpress.
        # order is the exactly like you set in $customOrder.
        foreach ($customOrder as $colname) {
            $new[$colname] = $columns[$colname];
        }
        return $new;
    }

    // Add the data to the custom columns for the emails post type:
    public function custom_bitcoindonate_column( $column, $post_id ) {
        switch ( $column ) {

            case 'bitcoindonate_shortcode' :
                echo '[webberdoo-btc-donate id='.$post_id.']';
                break;

            /*case 'voter_standard_result_shortcode' :
                echo '[wdoo-votr-standard-results id='.$post_id.']';
                break;*/


        }
    }



}