<?php
/**
 * Created by Freddie Annobil-Dodoo @ Webberdoo.co.uk
 */

namespace Webberdoo\BTC\App\Lib;

use Pimple\Container;

Class WdooPostTypes
{
    public $app;

    public function __construct(Container $app)
    {
        $this->app = $app;

    }

    public function init()
    {
        add_action('init', array($this, 'wdoo_custom_post_types'));
       // add_action('init', array($this, 'wdoo_custom_post_types_no_capabilities'));

    }

    public function wdoo_custom_post_types()
    {
        if(isset($this->app['config-posttypes']['post_type'])) {
            $sub_menu = $this->app['config-posttypes']['post_type'];
            foreach ($sub_menu as $key => $value) {

                $labels = array(
                    'name'               => $value['plural_name'],
                    'singular_name'      => $value['single_name'],
                    'menu_name'          => $value['plural_name'],
                    'name_admin_bar'     => $value['single_name'],
                    'add_new'            => 'Add New',
                    'add_new_item'       => 'Add New '.$value['single_name'],
                    'new_item'           => 'New '.$value['single_name'],
                    'edit_item'          => 'Edit '.$value['single_name'],
                    'view_item'          => 'View '.$value['single_name'],
                    'all_items'          => 'All '.$value['plural_name'],
                    'search_items'       => 'Search '.$value['plural_name'],
                    'parent_item_colon'  => 'Parent '.$value['plural_name'].':',
                    'not_found'          => 'No '.$value['plural_name'].' found.',
                    'not_found_in_trash' => 'No '.$value['plural_name'].' found in Trash.',
                );

                $args = array(
                    'labels'             => $labels,
                    'public'             => $value['public'],
                    'publicly_queryable' => $value['publicly_queryable'],
                    'show_ui'            => $value['show_ui'],
                    'show_in_menu'       => true,

                    'exclude_from_search' => $value['exclude_from_search'],  // you should exclude it from search results
                    'show_in_nav_menus' =>  $value['show_in_nav_menus'],  // you shouldn't be able to add it to menus
                    'show_in_rest'          => true,
                    'menu_icon'          => 'dashicons-editor-bold',
                    'query_var'          => true,
                    'rewrite'            => $value['rewrite'],
                    'capability_type'    => 'post',
                    'has_archive'        => $value['has_archive'],
                    'hierarchical'       => false,
                    'menu_position'      => $value['menu_position'],
                    'supports'           => $value['supports'],
                );

                register_post_type($value['custom_post_type_name'], $args);

                if(isset($value['taxonomies'])){
                    $tax = $value['taxonomies'];
                    foreach ($tax as $tax_key => $tax_value) {
                        //taxonomies
                        $this->wdoo_taxonomies(
                            $tax_value['taxonomy_name'],
                            $tax_value['single_name'],
                            $tax_value['plural_name'],
                            $tax_value['hierarchical'],
                            $tax_value['belongs_to_custom_post_type']
                        );
                    }
                }

            }// end foreach loop
        }


    }

    public function wdoo_taxonomies($taxonomy_name, $single_name, $plural_name, $hierarchical, $belongs_to_custom_post_type)
    {
        $labels = array(
            'name'              => $plural_name,
            'singular_name'     => $single_name,
            'search_items'      => $plural_name,
            'all_items'         => 'All '.$plural_name,
            'parent_item'       => 'Parent '.$single_name,
            'parent_item_colon' => 'Parent '.$single_name.':',
            'edit_item'         => 'Edit '.$single_name,
            'update_item'       => 'Update '.$single_name,
            'add_new_item'      => 'Add New A '.$single_name,
            'new_item_name'     => 'New '.$single_name,
            'menu_name'         => $plural_name,
        );

        $args = array(
            'hierarchical'      => $hierarchical,
            'labels'            => $labels,
            'show_ui'           => true,
            'show_admin_column' => true,
            'query_var'         => true,
            'rewrite'           => array( 'slug' => $taxonomy_name )
        );

        register_taxonomy( $taxonomy_name, array( $belongs_to_custom_post_type ), $args );

    }

    public function wdoo_custom_post_types_no_capabilities()
    {
        if(isset($this->app['config-posttypes_no_capabilities']['post_type'])) {
            $sub_menu = $this->app['config-posttypes_no_capabilities']['post_type'];
            foreach ($sub_menu as $key => $value) {

                $labels = array(
                    'name'               => $value['plural_name'],
                    'singular_name'      => $value['single_name'],
                    'menu_name'          => $value['plural_name'],
                    'name_admin_bar'     => $value['single_name'],
                    'add_new'            => 'Add New',
                    'add_new_item'       => 'Add New '.$value['single_name'],
                    'new_item'           => 'New '.$value['single_name'],
                    'edit_item'          => 'Edit '.$value['single_name'],
                    'view_item'          => 'View '.$value['single_name'],
                    'all_items'          => 'All '.$value['plural_name'],
                    'search_items'       => 'Search '.$value['plural_name'],
                    'parent_item_colon'  => 'Parent '.$value['plural_name'].':',
                    'not_found'          => 'No '.$value['plural_name'].' found.',
                    'not_found_in_trash' => 'No '.$value['plural_name'].' found in Trash.',
                );

                $args = array(
                    'labels'             => $labels,
                    'public'             => $value['public'],
                    'publicly_queryable' => $value['publicly_queryable'],
                    'show_ui'            => $value['show_ui'],
                    'show_in_menu'       => true,
                    'exclude_from_search' => $value['exclude_from_search'],  // you should exclude it from search results
                    'show_in_nav_menus' =>  $value['show_in_nav_menus'],  // you shouldn't be able to add it to menus
                    'show_in_rest'          => true,
                    'menu_icon'          => 'dashicons-yes',
                    'query_var'          => true,
                    'rewrite'            => $value['rewrite'],
                    'capability_type'    => 'post',
                    /*'capabilities' => array(
                        'create_posts' => true,
                    ),*/
                    'has_archive'        => $value['has_archive'],
                    'hierarchical'       => false,
                    'menu_position'      => $value['menu_position'],
                    'supports'           => $value['supports'],
                );

                register_post_type($value['custom_post_type_name'], $args);

                if(isset($value['taxonomies'])){
                    $tax = $value['taxonomies'];
                    foreach ($tax as $tax_key => $tax_value) {
                        //taxonomies
                        $this->wdoo_taxonomies(
                            $tax_value['taxonomy_name'],
                            $tax_value['single_name'],
                            $tax_value['plural_name'],
                            $tax_value['hierarchical'],
                            $tax_value['belongs_to_custom_post_type']
                        );
                    }
                }

            }// end foreach loop
        }


    }

}
















